## ENV
Prepare your server information file  
USER = <username>  
PASSWORD = <your_local_password>  
BACKUP_ADDRESS = <ip_address>  
BACKUP_USER = <user>  
BACKUP_PASSWORD = <password>  
BACKUP_SOURCE_PATH = <source_magento_path>  

## server-info
update this file for local deploy server and source server